@@ -159,7 +159,7 @@ B<Changes to JSON::XS>
 
 package Cpanel::JSON::XS;
 
-our $VERSION = '3.0203';
+our $VERSION = '3.0204';
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(encode_json decode_json to_json from_json);
@@ -1843,7 +1843,7 @@ sub false() { $false }
 sub is_bool($) {
   shift if @_ == 2; # as method call
   (ref($_[0]) and $_[0]->isa(JSON::PP::Boolean::))
-  or (exists $INC{'Types/Serializer.pm'} and Types::Serialiser::is_bool($_0))
+  or (exists $INC{'Types/Serializer.pm'} and Types::Serialiser::is_bool($_[0]))
 }
 
 XSLoader::load 'Cpanel::JSON::XS', $VERSION;
